@@ -1,7 +1,7 @@
 # library(testthat); library(devtools); load_all()
 context("intermediate-file")
 
-test_that("responses to intermediate file", {
+test_with_dir("responses to intermediate file", {
   dclean()
   config = dbug()
   testrun(config)
@@ -9,7 +9,7 @@ test_that("responses to intermediate file", {
   # check missing and then replace file exactly as before
   final0 = readd(final, search = FALSE)
   val = readRDS("intermediatefile.rds")
-  unlink("intermediatefile.rds")
+  unlink("intermediatefile.rds", force = TRUE)
   saveRDS(val, "intermediatefile.rds")
   testrun(config)
   nobuild(config)
@@ -22,7 +22,7 @@ test_that("responses to intermediate file", {
   expect_equal(final0, readd(final, search = FALSE))
   
   # break the intermediate file
-  unlink("intermediatefile.rds")
+  unlink("intermediatefile.rds", force = TRUE)
   testrun(config)
   expect_equal(justbuilt(config), "'intermediatefile.rds'")
   expect_equal(final0, readd(final, search = FALSE))
